@@ -12,20 +12,10 @@ from .http.http import HttpEnumeration
 from .ftp.ftp import FtpEnumeration
 from .nbt.nbt import NbtEnumeration
 
-def is_http(service, port, state):
-    """ Ruleset for classifying an http service."""
-    return (
-        'http' in service and 'proxy' not in service \
-        or port in ['8081']
-    ) and state == 'open'
-
-def is_ftp(service, port, state):
-    """ Ruleset for classifying an ftp service."""
-    return 'ftp' in service and state == 'open'
-
-def is_nbt(service, port, state):
-    """ Ruleset for classifying a netbios service."""
-    return port == '445' and state == 'open'
+http = HttpEnumeration()
+ftp = FtpEnumeration()
+nbt = NbtEnumeration()
+service_modules = [http, ftp, nbt]
 
 def receive_service_data(sender=None, **flags):
     """Receive data either directly (not implemented) or via signal. Delegate 
@@ -43,22 +33,10 @@ def receive_service_data(sender=None, **flags):
     udp_services = results[ip]['udp']
 
     for tcp_service in tcp_services:
-        service, port, state = tcp_service.get('service'), tcp_service.get('port'), tcp_service.get('state')
-
-        if is_http(service, port, state):
-            http = HttpEnumeration()
-            http.scan(ip, port, working_directory)
-
-        if is_ftp(service, port, state):
-            ftp = FtpEnumeration()
-            ftp.scan(ip, port, working_directory)
-
-        if is_nbt(service, port, state):
-            nbt = NbtEnumeration()
-            nbt.scan(ip, working_directory)
-
-    # TODO: When UDP service enumeration tools are available, do as I'm doing above.
-
+        service, port = tcp_service.get('service'), tcp_service.get('port')
+        for module in service_modules:
+            if module.is_valid_service(tcp_service):
+                module.scan(working_directory, dict(ip=ip, port=port))
 
 if __name__ == '__main__':
     # TODO: Possibly set up delegator module to accept a json file of
